# This file is auto-generated. Do not edit manually.

from typing import TypedDict, Optional


class Address(TypedDict, total=False):
    """State."""
    state: Optional[str]
    """Country."""
    country: Optional[str]
    """Region."""
    region: Optional[str]
    """City."""
    city: Optional[str]
    """Address line 1."""
    line1: Optional[str]
    """Address line 2."""
    line2: Optional[str]
    """Postal code."""
    postal_code: Optional[str]
