# This file is auto-generated. Do not edit manually.

from typing import TypedDict, Optional, List, Literal


class SubscriptionInput(TypedDict, total=False):
    """Modify fee quantities for the subscription plans and fees."""
    items: Optional[List[dict]]
    """Plan ID associated with the subscription."""
    plan_id: Optional[str]
    """Billing cycle type of the subscription."""
    billing_cycle_type: Optional[Literal["anniversary", "calendar"]]
    """Payment method ID associated with the subscription. Required if collection_method is `automatic`."""
    payment_method_id: Optional[str]
    """Trial period of the subscription in days. Overrides the plan's trial period if set."""
    trial_period_days: Optional[int]
    """Payment collection method for invoices generated by the subscription."""
    collection_method: Optional[str]
